# ProgettoBIO

The documentation can be seen at https://pier297.github.io/ProgettoBIO/

## To run the server

> export FLASK_APP=server

> python server.py

Then head over to the react client (https://github.com/Pier297/BioSearch)
and execute:

> npm start

To generate the doc run:

> pdoc -o docs/ pubmad/pipeline.py pubmad/utils.py pubmad/types.py --logo logo.png